diff --git a/dependencies.xml b/dependencies.xml
index 7eb6335591..48f0088585 100644
--- a/dependencies.xml
+++ b/dependencies.xml
@@ -40,7 +40,7 @@ Note all install methods after "main" take
3.21.6
- 1.15
+ 2.03
diff --git a/developer_tools/XSDSchemas/raven.xsd b/developer_tools/XSDSchemas/raven.xsd
index 36f0f7e6ee..cefcccb7fa 100644
--- a/developer_tools/XSDSchemas/raven.xsd
+++ b/developer_tools/XSDSchemas/raven.xsd
@@ -95,6 +95,7 @@
+
diff --git a/doc/user_guide/ravenRomTrainer.tex b/doc/user_guide/ravenRomTrainer.tex
index 997ef81fe0..1663ceb3f5 100644
--- a/doc/user_guide/ravenRomTrainer.tex
+++ b/doc/user_guide/ravenRomTrainer.tex
@@ -178,8 +178,7 @@ \subsubsection{How to load and sample a ROM?}
\textbf{Files} object to track the pickled ROM file.
\xmlExample{framework/user_guide/ravenTutorial/RomLoad.xml}{Files}
-In this example, the subtype \xmlString{NDinvDistWeight} of \xmlNode{ROM} is used instead of \xmlString{pickledROM},
-since the subtype of ROM is already known.
+In this example, the subtype \xmlString{pickledROM} of \xmlNode{ROM} is used since the hyper-parameters of the ROM can not be changed once the ROM is loaded from a pickled (serialized) file.
\xmlExample{framework/user_guide/ravenTutorial/RomLoad.xml}{Models}
Two data objects are defined: 1) a \textbf{HistorySet} named ``inputPlaceHolder'' used as a placeholder input for
diff --git a/doc/user_manual/runInfo.tex b/doc/user_manual/runInfo.tex
index 091fdb2e14..f5cccd8bb5 100644
--- a/doc/user_manual/runInfo.tex
+++ b/doc/user_manual/runInfo.tex
@@ -59,6 +59,19 @@ \subsection{RunInfo: Input of Calculation Flow}
%
\default{mpiexec}
+ %%%%%% N THREADS
+\item \xmlNode{threadParameter}, \xmlDesc{string, optional field}, specifies the command used to set the
+ number of threads. The ``%NUM_CPUS%'' is a wildcard that will be replaced by the number of threads
+ specified in the node \xmlNode{NumThreads}. In this way for commands
+ that require the number of threads to be inputted without a blank space after this command,
+ the user can specify the command attaching the wildcard above to the string reporting the command.
+ For example, $--my-nthreads=%NUM_CPUS%$ (e.g. $--my-nthreads=10$). In other cases, the command can be
+ inputted explicetely adding the blank space. For example, $-omp %NUM_CPUS%$ (e.g. $-omp 10$).
+ If the wild card is not present, a blank space is always added after the command
+ (e.g. $--mycommand => --mycommand 10$).
+ %
+ \default{--n-threads=\%NUM\_CPUS\%}
+
%%%%%% BATCH SIZE
\item \xmlNode{batchSize}, \xmlDesc{integer, optional field},
specifies the number of parallel runs executed simultaneously (e.g.,
@@ -125,7 +138,8 @@ \subsection{RunInfo: Input of Calculation Flow}
For example, if RAVEN is driving a code named ``FOO,'' and this code has
multi-threading support, this block is used to specify how many threads each
instance of FOO should use (e.g. ``\texttt{FOO --n-threads=N}'' where \texttt{N}
- is the number of threads).
+ is the number of threads). The command to specify the number of threads can be
+customized via the node \xmlNode{threadParameter}.
%
\default{1 (or None when the driven code does not have multi-threading
support)}
diff --git a/framework/CustomModes/MPILegacySimulationMode.py b/framework/CustomModes/MPILegacySimulationMode.py
index 94f698bd14..c10d14a1df 100644
--- a/framework/CustomModes/MPILegacySimulationMode.py
+++ b/framework/CustomModes/MPILegacySimulationMode.py
@@ -201,7 +201,8 @@ def modifyInfo(self, runInfoDict):
newRunInfo['precommand'] = runInfoDict["MPIExec"]+" "+nodeCommand+" -n "+str(numMPI)+" "+runInfoDict['precommand']
if(runInfoDict['NumThreads'] > 1):
#add number of threads to the post command.
- newRunInfo['postcommand'] = " --n-threads=%NUM_CPUS% "+runInfoDict['postcommand']
+ newRunInfo['threadParameter'] = runInfoDict['threadParameter']
+ newRunInfo['postcommand'] =" {} {}".format(newRunInfo['threadParameter'],runInfoDict['postcommand'])
self.raiseAMessage("precommand: "+newRunInfo['precommand']+", postcommand: "+newRunInfo.get('postcommand',runInfoDict['postcommand']))
return newRunInfo
diff --git a/framework/CustomModes/MPISimulationMode.py b/framework/CustomModes/MPISimulationMode.py
index 2d0292ab1c..7457f5eec9 100644
--- a/framework/CustomModes/MPISimulationMode.py
+++ b/framework/CustomModes/MPISimulationMode.py
@@ -109,9 +109,9 @@ def modifyInfo(self, runInfoDict):
# Note, with defaults the precommand is "mpiexec -f nodeFile -n numMPI"
newRunInfo['precommand'] = runInfoDict["MPIExec"]+" "+nodeCommand+" -n "+str(numMPI)+" "+runInfoDict['precommand']
if runInfoDict['NumThreads'] > 1:
+ newRunInfo['threadParameter'] = runInfoDict['threadParameter']
#add number of threads to the post command.
- newRunInfo['postcommand'] = " --n-threads=%NUM_CPUS% "+runInfoDict['postcommand']
-
+ newRunInfo['postcommand'] =" {} {}".format(newRunInfo['threadParameter'],runInfoDict['postcommand'])
self.raiseAMessage("precommand: "+newRunInfo['precommand']+", postcommand: "+newRunInfo.get('postcommand',runInfoDict['postcommand']))
return newRunInfo
diff --git a/framework/Optimizers/parentSelectors/parentSelectors.py b/framework/Optimizers/parentSelectors/parentSelectors.py
index 5f13de81fe..0be3ca8396 100644
--- a/framework/Optimizers/parentSelectors/parentSelectors.py
+++ b/framework/Optimizers/parentSelectors/parentSelectors.py
@@ -91,29 +91,55 @@ def tournamentSelection(population,**kwargs):
fitness = kwargs['fitness']
nParents= kwargs['nParents']
pop = population
-
popSize = population.values.shape[0]
+ if 'rank' in kwargs:
+ # the key rank is used in multi-objective optimization where rank identifies which front the point belongs to
+ rank = kwargs['rank']
+ multiObjectiveRanking = True
+ matrixOperationRaw = np.zeros((popSize,3))
+ matrixOperationRaw[:,0] = np.transpose(np.arange(popSize))
+ matrixOperationRaw[:,1] = np.transpose(fitness.data)
+ matrixOperationRaw[:,2] = np.transpose(rank.data)
+ matrixOperation = np.zeros((popSize,3))
+ else:
+ multiObjectiveRanking = False
+ matrixOperationRaw = np.zeros((popSize,2))
+ matrixOperationRaw[:,0] = np.transpose(np.arange(popSize))
+ matrixOperationRaw[:,1] = np.transpose(fitness.data)
+ matrixOperation = np.zeros((popSize,2))
+
+ indexes = list(np.arange(popSize))
+ indexesShuffled = randomUtils.randomChoice(indexes, size = popSize, replace = False, engine = None)
+
+ for idx, val in enumerate(indexesShuffled):
+ matrixOperation[idx,:] = matrixOperationRaw[val,:]
+
selectedParent = xr.DataArray(
- np.zeros((nParents,np.shape(pop)[1])),
- dims=['chromosome','Gene'],
- coords={'chromosome':np.arange(nParents),
- 'Gene': kwargs['variables']})
-
- if nParents >= popSize/2.0:
- # generate combination of 2 with replacement
- selectionList = np.atleast_2d(randomUtils.randomChoice(list(range(0,popSize)), 2*nParents, replace=False))
- else: # nParents < popSize/2.0
- # generate combination of 2 without replacement
- selectionList = np.atleast_2d(randomUtils.randomChoice(list(range(0,popSize)), 2*nParents))
-
- selectionList = selectionList.reshape(nParents,2)
-
- for index,pair in enumerate(selectionList):
- if fitness[pair[0]]>fitness[pair[1]]:
- selectedParent[index,:] = pop.values[pair[0],:]
- else: # fitness[pair[1]]>fitness[pair[0]]:
- selectedParent[index,:] = pop.values[pair[1],:]
+ np.zeros((nParents,np.shape(pop)[1])),
+ dims=['chromosome','Gene'],
+ coords={'chromosome':np.arange(nParents),
+ 'Gene': kwargs['variables']})
+
+ if not multiObjectiveRanking: # single-objective implementation of tournamentSelection
+ for i in range(nParents):
+ if matrixOperation[2*i,1] > matrixOperation[2*i+1,1]:
+ index = int(matrixOperation[i,0])
+ else:
+ index = int(matrixOperation[i+1,0])
+ selectedParent[i,:] = pop.values[index,:]
+ else: # multi-objective implementation of tournamentSelection
+ for i in range(nParents-1):
+ if matrixOperation[2*i,2] > matrixOperation[2*i+1,2]:
+ index = int(matrixOperation[i,0])
+ elif matrixOperation[2*i,2] < matrixOperation[2*i+1,2]:
+ index = int(matrixOperation[i+1,0])
+ else: # same rank case
+ if matrixOperation[2*i,1] > matrixOperation[2*i+1,1]:
+ index = int(matrixOperation[i,0])
+ else:
+ index = int(matrixOperation[i+1,0])
+ selectedParent[i,:] = pop.values[index,:]
return selectedParent
diff --git a/framework/Simulation.py b/framework/Simulation.py
index d7a059f8f3..0035653fd7 100644
--- a/framework/Simulation.py
+++ b/framework/Simulation.py
@@ -215,34 +215,41 @@ def __init__(self, frameworkDir, verbosity='all', interactive=Interaction.No):
sys.path.append(os.getcwd())
#this dictionary contains the general info to run the simulation
self.runInfoDict = {}
- self.runInfoDict['DefaultInputFile' ] = 'test.xml' #Default input file to use
- self.runInfoDict['SimulationFiles' ] = [] #the xml input file
+ self.runInfoDict['DefaultInputFile' ] = 'test.xml' #Default input file to use
+ self.runInfoDict['SimulationFiles' ] = [] #the xml input file
self.runInfoDict['ScriptDir' ] = os.path.join(os.path.dirname(frameworkDir),"scripts") # the location of the pbs script interfaces
- self.runInfoDict['FrameworkDir' ] = frameworkDir # the directory where the framework is located
+ self.runInfoDict['FrameworkDir' ] = frameworkDir # the directory where the framework is located
self.runInfoDict['RemoteRunCommand' ] = os.path.join(frameworkDir,'raven_qsub_command.sh')
- self.runInfoDict['NodeParameter' ] = '-f' # the parameter used to specify the files where the nodes are listed
- self.runInfoDict['MPIExec' ] = 'mpiexec' # the command used to run mpi commands
- self.runInfoDict['WorkingDir' ] = '' # the directory where the framework should be running
- self.runInfoDict['TempWorkingDir' ] = '' # the temporary directory where a simulation step is run
- self.runInfoDict['NumMPI' ] = 1 # the number of mpi process by run
- self.runInfoDict['NumThreads' ] = 1 # Number of Threads by run
- self.runInfoDict['numProcByRun' ] = 1 # Total number of core used by one run (number of threads by number of mpi)
- self.runInfoDict['batchSize' ] = 1 # number of contemporaneous runs
- self.runInfoDict['internalParallel' ] = False # activate internal parallel (parallel python). If True parallel python is used, otherwise multi-threading is used
- self.runInfoDict['ParallelCommand' ] = '' # the command that should be used to submit jobs in parallel (mpi)
- self.runInfoDict['ThreadingCommand' ] = '' # the command should be used to submit multi-threaded
- self.runInfoDict['totalNumCoresUsed' ] = 1 # total number of cores used by driver
- self.runInfoDict['queueingSoftware' ] = '' # queueing software name
- self.runInfoDict['stepName' ] = '' # the name of the step currently running
- self.runInfoDict['precommand' ] = '' # Add to the front of the command that is run
- self.runInfoDict['postcommand' ] = '' # Added after the command that is run.
- self.runInfoDict['delSucLogFiles' ] = False # If a simulation (code run) has not failed, delete the relative log file (if True)
- self.runInfoDict['deleteOutExtension'] = [] # If a simulation (code run) has not failed, delete the relative output files with the listed extension (comma separated list, for example: 'e,r,txt')
- self.runInfoDict['mode' ] = '' # Running mode. Curently the only mode supported is mpi but others can be added with custom modes.
- self.runInfoDict['Nodes' ] = [] # List of node IDs. Filled only in case RAVEN is run in a DMP machine
- self.runInfoDict['expectedTime' ] = '10:00:00' # How long the complete input is expected to run.
+ self.runInfoDict['NodeParameter' ] = '-f' # the parameter used to specify the files where the nodes are listed
+ self.runInfoDict['MPIExec' ] = 'mpiexec' # the command used to run mpi commands
+ self.runInfoDict['threadParameter'] = '--n-threads=%NUM_CPUS%'# the command used to run multi-threading commands.
+ # The "%NUM_CPUS%" is a wildcard to replace. In this way for commands
+ # that require the num of threads to be inputted without a
+ # blank space we can have something like --my-nthreads=%NUM_CPUS%
+ # (e.g. --my-nthreads=10), otherwise we can have something like
+ # -omp %NUM_CPUS% (e.g. -omp 10). If not present, a blank
+ # space is always added (e.g. --mycommand => --mycommand 10)
+ self.runInfoDict['WorkingDir' ] = '' # the directory where the framework should be running
+ self.runInfoDict['TempWorkingDir' ] = '' # the temporary directory where a simulation step is run
+ self.runInfoDict['NumMPI' ] = 1 # the number of mpi process by run
+ self.runInfoDict['NumThreads' ] = 1 # Number of Threads by run
+ self.runInfoDict['numProcByRun' ] = 1 # Total number of core used by one run (number of threads by number of mpi)
+ self.runInfoDict['batchSize' ] = 1 # number of contemporaneous runs
+ self.runInfoDict['internalParallel' ] = False # activate internal parallel (parallel python). If True parallel python is used, otherwise multi-threading is used
+ self.runInfoDict['ParallelCommand' ] = '' # the command that should be used to submit jobs in parallel (mpi)
+ self.runInfoDict['ThreadingCommand' ] = '' # the command should be used to submit multi-threaded
+ self.runInfoDict['totalNumCoresUsed' ] = 1 # total number of cores used by driver
+ self.runInfoDict['queueingSoftware' ] = '' # queueing software name
+ self.runInfoDict['stepName' ] = '' # the name of the step currently running
+ self.runInfoDict['precommand' ] = '' # Add to the front of the command that is run
+ self.runInfoDict['postcommand' ] = '' # Added after the command that is run.
+ self.runInfoDict['delSucLogFiles' ] = False # If a simulation (code run) has not failed, delete the relative log file (if True)
+ self.runInfoDict['deleteOutExtension'] = [] # If a simulation (code run) has not failed, delete the relative output files with the listed extension (comma separated list, for example: 'e,r,txt')
+ self.runInfoDict['mode' ] = '' # Running mode. Curently the only mode supported is mpi but others can be added with custom modes.
+ self.runInfoDict['Nodes' ] = [] # List of node IDs. Filled only in case RAVEN is run in a DMP machine
+ self.runInfoDict['expectedTime' ] = '10:00:00' # How long the complete input is expected to run.
self.runInfoDict['logfileBuffer' ] = int(io.DEFAULT_BUFFER_SIZE)*50 # logfile buffer size in bytes
- self.runInfoDict['clusterParameters' ] = [] # Extra parameters to use with the qsub command.
+ self.runInfoDict['clusterParameters' ] = [] # Extra parameters to use with the qsub command.
self.runInfoDict['maxQueueSize' ] = None
#Following a set of dictionaries that, in a manner consistent with their names, collect the instance of all objects needed in the simulation
@@ -586,6 +593,8 @@ def __readRunInfo(self,xmlNode,runInfoSkip,xmlFilename):
self.runInfoDict['NodeParameter'] = element.text.strip()
elif element.tag == 'MPIExec':
self.runInfoDict['MPIExec'] = element.text.strip()
+ elif element.tag == 'threadParameter':
+ self.runInfoDict['threadParameter'] = element.text.strip()
elif element.tag == 'JobName':
self.runInfoDict['JobName' ] = element.text.strip()
elif element.tag == 'ParallelCommand':
diff --git a/framework/SupervisedLearning/KerasClassifier.py b/framework/SupervisedLearning/KerasClassifier.py
index 1b344710be..f17992c5bc 100644
--- a/framework/SupervisedLearning/KerasClassifier.py
+++ b/framework/SupervisedLearning/KerasClassifier.py
@@ -139,9 +139,7 @@ def __evaluateLocal__(self,featureVals):
"""
featureVals = self._preprocessInputs(featureVals)
prediction = {}
- with self.graph.as_default():
- tf.keras.backend.set_session(self._session)
- outcome = self._ROM.predict(featureVals)
+ outcome = self._ROM.predict(featureVals)
if self.numClasses > 1 and self.lossFunction in ['categorical_crossentropy']:
outcome = np.argmax(outcome,axis=1)
# Transform labels back to original encoding
diff --git a/framework/SupervisedLearning/KerasRegression.py b/framework/SupervisedLearning/KerasRegression.py
index 8f7d4dba28..ddc062b938 100644
--- a/framework/SupervisedLearning/KerasRegression.py
+++ b/framework/SupervisedLearning/KerasRegression.py
@@ -168,9 +168,7 @@ def __evaluateLocal__(self,featureVals):
"""
featureVals = self._preprocessInputs(featureVals)
prediction = {}
- with self.graph.as_default():
- tf.keras.backend.set_session(self._session)
- outcome = self._ROM.predict(featureVals)
+ outcome = self._ROM.predict(featureVals)
for i, target in enumerate(self.target):
prediction[target] = self._invertScaleToNormal(outcome[0, :, i], target)
return prediction
diff --git a/scripts/establish_conda_env.sh b/scripts/establish_conda_env.sh
index 49bdec2bb8..44eefa0188 100755
--- a/scripts/establish_conda_env.sh
+++ b/scripts/establish_conda_env.sh
@@ -74,6 +74,25 @@ function find_conda_defs ()
CONDA_DEFS="${CONDA_DEFS//\\//}"
}
+function guess_conda_defs ()
+{
+ if [ -z ${CONDA_DEFS} ];
+ then
+ CONDA_DEFS=$(which conda | tail -1)
+ if [[ "$CONDA_DEFS" != "" ]]; then
+ # we found it
+ LOCATION_CONDASH="etc/profile.d/conda.sh"
+ if [[ "$CONDA_PATH" == *"condabin"* ]]; then
+ CONDA_DEFS=`echo "${CONDA_DEFS/condabin\/conda/$LOCATION_CONDASH}"`
+ else
+ CONDA_DEFS=`echo "${CONDA_DEFS/bin\/conda/$LOCATION_CONDASH}"`
+ fi
+ # fix Windows backslashes to be forward, compatible with all *nix including mingw
+ CONDA_DEFS="${CONDA_DEFS//\\//}"
+ fi
+ fi
+}
+
function install_libraries()
{
if [[ $ECE_VERBOSE == 0 ]]; then echo Installing libraries ...; fi
@@ -368,9 +387,17 @@ if [[ "$INSTALL_MANAGER" == "CONDA" ]];
# conda info || echo conda info failed
#fi
else
- echo ... Conda definitions not found at \"${CONDA_DEFS}\"!
- echo ... \>\> Specify the location of miniconda3/etc/profile.d/conda.sh through the --conda-defs option.
- exit 1
+ # try to guess
+ guess_conda_defs
+ if test -e ${CONDA_DEFS};
+ then
+ if [[ $ECE_VERBOSE == 0 ]]; then echo ... Found conda definitions at ${CONDA_DEFS}; fi
+ source ${CONDA_DEFS}
+ else
+ echo ... Conda definitions not found at \"${CONDA_DEFS}\"!
+ echo ... \>\> Specify the location of miniconda3/etc/profile.d/conda.sh through the --conda-defs option.
+ exit 1
+ fi
fi
else
# check if pip exists
diff --git a/tests/cluster_tests/test_mpiqsub_nosplit.xml b/tests/cluster_tests/test_mpiqsub_nosplit.xml
index 83255e8294..8cf8bf04ac 100644
--- a/tests/cluster_tests/test_mpiqsub_nosplit.xml
+++ b/tests/cluster_tests/test_mpiqsub_nosplit.xml
@@ -16,6 +16,7 @@
3-W block=true1
+ --n-threads=%NUM_CPUS%
mpilegacy
diff --git a/tests/framework/Optimizers/GeneticAlgorithms/GA_knapsackBaseTournament.xml b/tests/framework/Optimizers/GeneticAlgorithms/GA_knapsackBaseTournament.xml
new file mode 100644
index 0000000000..92886da352
--- /dev/null
+++ b/tests/framework/Optimizers/GeneticAlgorithms/GA_knapsackBaseTournament.xml
@@ -0,0 +1,155 @@
+
+
+
+ framework/Optimizers/GeneticAlgorithms/GA_knapsackBaseTournament
+ mandd
+ 2021-06-22
+ GeneticAlgorithm
+
+ This test is designed to find the optimal solution of a basic knapsack problem using tournament select
+
+
+
+
+ simpleKnapsack
+ opt, print, printExport
+ 1
+ False
+
+
+
+
+ placeholder
+ Kbase
+ GAoptimizer
+ opt_export
+
+
+
+ optOut
+
+
+
+ opt_export
+
+
+
+
+
+
+ 0
+ 1
+ withReplacement
+
+
+
+
+
+
+ 5
+ 42
+ final
+
+
+
+ 14
+
+
+ 0.9
+
+
+ 0.1
+
+
+
+ 0.2
+ 13.0
+
+ tournamentSelection
+ fitnessBased
+
+
+
+ -1
+
+
+
+ unif_dist_wRepl
+ 0,0,0,0,1,0,0,0,0,1,0,0,0,0
+
+
+ unif_dist_wRepl
+ 0,0,0,1,0,0,0,0,1,0,0,0,0,1
+
+
+ unif_dist_wRepl
+ 0,0,1,0,0,0,0,1,0,0,0,0,1,0
+
+
+ unif_dist_wRepl
+ 0,1,0,0,0,0,1,0,0,0,0,1,0,0
+
+
+ unif_dist_wRepl
+ 1,0,0,0,0,1,0,0,0,0,1,0,0,0
+
+
+ unif_dist_wRepl
+ 0,0,0,0,1,0,0,0,0,1,0,0,0,0
+
+
+ unif_dist_wRepl
+ 0,0,0,1,0,0,0,0,1,0,0,0,0,1
+
+
+ unif_dist_wRepl
+ 0,0,1,0,0,0,0,1,0,0,0,0,1,0
+
+
+ unif_dist_wRepl
+ 0,1,0,0,0,0,1,0,0,0,0,1,0,0
+
+
+ unif_dist_wRepl
+ 1,0,0,0,0,1,0,0,0,0,1,0,0,0
+
+
+ planValue
+ optOut
+
+
+
+
+
+ proj1,proj2,proj3,proj4,proj5,proj6,proj7,proj8,proj9,proj10,planValue,validPlan
+
+
+
+
+
+
+ proj1,proj2,proj3,proj4,proj5,proj6,proj7,proj8,proj9,proj10
+
+
+
+ proj1,proj2,proj3,proj4,proj5,proj6,proj7,proj8,proj9,proj10
+
+
+
+ trajID
+
+
+
+
+
+
+ csv
+
+
+
+ csv
+
+
+
+
+
diff --git a/tests/framework/Optimizers/GeneticAlgorithms/gold/simpleKnapsack/PrintOptOut_1.csv b/tests/framework/Optimizers/GeneticAlgorithms/gold/simpleKnapsack/PrintOptOut_1.csv
new file mode 100644
index 0000000000..8f133488cb
--- /dev/null
+++ b/tests/framework/Optimizers/GeneticAlgorithms/gold/simpleKnapsack/PrintOptOut_1.csv
@@ -0,0 +1,135 @@
+proj1,proj2,proj3,proj4,proj5,proj6,proj7,proj8,proj9,proj10,planValue,validPlan,ProbabilityWeight-proj8,ProbabilityWeight-proj3,ProbabilityWeight-proj2,ProbabilityWeight-proj7,ProbabilityWeight-proj9,ProbabilityWeight-proj1,ProbabilityWeight,ProbabilityWeight-proj6,ProbabilityWeight-proj4,ProbabilityWeight-proj10,PointProbability,prefix,ProbabilityWeight-proj5,batchId
+0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,5,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,1,0.5,1
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,4,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,1,0.5,1
+0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,8,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,1,0.5,1
+0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,1,0.5,1
+1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,3,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,1,0.5,1
+0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,5,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,1,0.5,1
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,4,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,1,0.5,1
+0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,8,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,1,0.5,1
+0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,1,0.5,1
+1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,3,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,1,0.5,1
+0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,5,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,1,0.5,1
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,4,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,1,0.5,1
+0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,8,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,1,0.5,1
+0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,1,0.5,1
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,4,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,5,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,2,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+1.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,1.0,0.0,3,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,1.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,4,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,0.0,1.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,1,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+1.0,0.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,-2,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+1.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0,5,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,4,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+1.0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,5,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,4,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,4,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,0.0,1.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,2,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,4,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,0.0,0.0,1.0,0.0,0.0,1.0,0.0,0.0,0.0,-1,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,1.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0,0.0,5,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,1.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0,0.0,5,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,0.0,0.0,1.0,0.0,1.0,0.0,0.0,0.0,0.0,4,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,3,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,0.0,0.0,0.0,0.0,1.0,0.0,1.0,0.0,0.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+1.0,0.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,-2,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,1.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,5,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,0.0,2,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,1.0,0.0,6,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,0.0,2,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,1.0,0.0,4,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,0.0,1.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,1,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,1.0,0.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,7,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,2,0.5,2
+0.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,1.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,1.0,0.0,0.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0,4,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,0.0,1.0,0.0,1.0,0.0,1.0,0.0,0.0,0,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,0.0,0.0,0.0,1.0,0.0,1.0,0.0,0.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,1.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,5,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,5,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,0.0,0.0,0.0,1.0,0.0,1.0,0.0,0.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,8,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,1.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,0.0,1.0,0.0,1.0,0.0,0.0,0.0,0.0,4,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,0.0,1.0,0.0,0.0,1.0,0.0,0.0,0.0,-1,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,1.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0,7,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,1.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,1.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,4,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,1.0,1.0,0.0,0.0,0.0,0.0,0.0,1.0,2,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,1.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,5,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,1.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,0.0,2,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,1.0,4,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,1.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,8,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,3,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,1.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,2,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,4,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,1.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,1,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,3,0.5,3
+0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,1.0,4,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,0.0,2,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,1.0,4,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,0.0,2,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0,8,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,0.0,0.0,0.0,1.0,1.0,0.0,1.0,0.0,0.0,-1,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,0.0,1.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,1,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,0.0,0.0,0.0,0.0,1.0,0.0,1.0,0.0,0.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,0.0,1.0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,5,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,1.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,1.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+1.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0,5,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,0.0,0.0,0.0,1.0,0.0,1.0,0.0,0.0,1.0,0,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,0.0,2,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,1.0,2,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,0.0,2,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,1.0,2,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,0.0,0.0,1.0,1.0,0.0,0.0,0.0,0.0,1.0,7,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,1.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0,7,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,0.0,0.0,1.0,0.0,0.0,1.0,0.0,0.0,0.0,-1,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,1.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,0.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,1.0,-1,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0,1.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,1.0,0.0,0.0,1.0,0.0,1.0,0.0,0.0,0.0,1,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,0.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,1.0,-1,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,0.0,0.0,0.0,1.0,0.0,1.0,0.0,0.0,1.0,0,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,1.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0,7,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,4,0.5,4
+0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,8,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,1.0,0.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,7,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,1.0,4,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,1.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,0.0,1.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,1,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,1.0,0.0,0.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,0.0,1.0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,5,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,1.0,0.0,0.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,0.0,1.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,2,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,1.0,0.0,0.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,1.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,1.0,0.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,7,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,1.0,0.0,0.0,0.0,0.0,0.0,1.0,0.0,1.0,11,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,0.0,0.0,1.0,1.0,0.0,0.0,0.0,0.0,0.0,3,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,1.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,5,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,1.0,0.0,0.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,1.0,0.0,0.0,0.0,0.0,0.0,1.0,0.0,1.0,11,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,0.0,2,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,1.0,0.0,1.0,1.0,0.0,0.0,0.0,0.0,1.0,2,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0,4,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0,1.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,0.0,1.0,1.0,0.0,0.0,0.0,0.0,0.0,0.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,1.0,1.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,7,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,1.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,1.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,0.0,1.0,1.0,1.0,0.0,0.0,0.0,0.0,0.0,5,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,0.0,0.0,1.0,1.0,1.0,0.0,0.0,0.0,0.0,1,1.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,0.0,0.0,1.0,0.0,1.0,0.0,0.0,0.0,0.0,4,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,0.0,1.0,1.0,0.0,0.0,0.0,0.0,0.0,0.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
+0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,1.0,6,0.0,0.5,0.5,0.5,0.5,0.5,0.5,1,0.5,0.5,0.5,0.0009765625,5,0.5,5
diff --git a/tests/framework/Optimizers/GeneticAlgorithms/gold/simpleKnapsack/PrintOptOut_export_1.csv b/tests/framework/Optimizers/GeneticAlgorithms/gold/simpleKnapsack/PrintOptOut_export_1.csv
new file mode 100644
index 0000000000..46dbd37daf
--- /dev/null
+++ b/tests/framework/Optimizers/GeneticAlgorithms/gold/simpleKnapsack/PrintOptOut_export_1.csv
@@ -0,0 +1,2 @@
+trajID,proj1,proj2,proj3,proj4,proj5,proj6,proj7,proj8,proj9,proj10,planValue
+0,0.0,1.0,0.0,0.0,0.0,0.0,0.0,1.0,0.0,0.0,7
diff --git a/tests/framework/Optimizers/GeneticAlgorithms/tests b/tests/framework/Optimizers/GeneticAlgorithms/tests
index 4130c18bc6..1aecf33901 100644
--- a/tests/framework/Optimizers/GeneticAlgorithms/tests
+++ b/tests/framework/Optimizers/GeneticAlgorithms/tests
@@ -132,6 +132,16 @@
rel_err = 0.001
[../]
[../]
+
+ [./GA_knapsackBaseTournament]
+ type = 'RavenFramework'
+ input = 'GA_knapsackBaseTournament.xml'
+ [./csv]
+ type = OrderedCSV
+ output = 'simpleKnapsack/PrintOptOut_export_1.csv simpleKnapsack/PrintOptOut_1.csv'
+ rel_err = 0.001
+ [../]
+ [../]
[./GA_knapsackBaseUnifXover]
type = 'RavenFramework'
diff --git a/tests/framework/ROM/tensorflow_keras/gold/LSTMRegression/out_resampled_0.csv b/tests/framework/ROM/tensorflow_keras/gold/LSTMRegression/out_resampled_0.csv
index 98a0e61a3a..e36af7c657 100644
--- a/tests/framework/ROM/tensorflow_keras/gold/LSTMRegression/out_resampled_0.csv
+++ b/tests/framework/ROM/tensorflow_keras/gold/LSTMRegression/out_resampled_0.csv
@@ -1,102 +1,102 @@
index,sum,square,prev_sum,prev_square,prev_square_sum
-0,0.278171479702,23.6013278961,0.0,0.0,0.0
-1,0.310073494911,24.0132160187,-7.57264440482,57.3449432818,31.7160669424
-2,0.262860447168,24.8723106384,-7.87435645452,62.0054895729,35.3035396515
-3,0.136635601521,25.8636074066,-8.07870057495,65.2654029798,38.1221882131
-4,-0.0360126793385,26.7971458435,-8.18096117119,66.9281256846,39.9580643964
-5,-0.215114802122,27.5582141876,-8.17805981355,66.880662314,40.6626090155
-6,-0.369623988867,28.0884933472,-8.06861057073,65.1024765422,40.162889391
-7,-0.482978194952,28.3720283508,-7.85294698564,61.6687763592,38.4667574053
-8,-0.550806999207,28.4187908173,-7.53312022945,56.7479003913,35.662578878
-9,-0.576100945473,28.2493228912,-7.11286845588,50.5928976706,31.9135498803
-10,-0.565454483032,27.8854904175,-6.59755786267,43.5277697512,27.4469794863
-11,-0.527402281761,27.3491477966,-5.99409644477,35.9291921892,22.5392568497
-12,-0.472146183252,26.6672477722,-5.31082188387,28.2048290822,17.4975106529
-13,-0.410991460085,25.87915802,-4.55736545507,20.769579891,12.6391914008
-14,-0.353814035654,25.0398197174,-3.74449423598,14.0212370833,8.27094676353
-15,-0.305222958326,24.2138957977,-2.88393426929,8.31707686959,4.66820782895
-16,-0.263186722994,23.4624919891,-1.98817765084,3.95285037132,2.05685648579
-17,-0.222431838512,22.8300628662,-1.0702767866,1.14549239994,0.59820444152
-18,-0.179612457752,22.3390750885,-0.143629277806,0.0206293694431,0.378291958227
-19,-0.135696560144,21.9940471649,0.778242948154,0.605662086351,1.40222422628
-20,-0.094630241394,21.7906665802,1.68191654683,2.82884327049,3.59392488599
-21,-0.0604230463505,21.7245197296,2.55428795712,6.52438696786,6.80132229929
-22,-0.0348331332207,21.7957763672,3.3827891733,11.443262591,10.8066192267
-23,-0.0165946483612,22.008190155,4.15559446071,17.2689653219,15.3409551072
-24,-0.00222283601761,22.362575531,4.86181453988,23.6372406202,20.1024751237
-25,0.0120401233435,22.8479347229,5.4916749756,30.1584940376,24.7765914869
-26,0.0280865579844,23.4356994629,6.03667577376,36.4414543975,29.0570752678
-27,0.0450486987829,24.0801010132,6.48972950603,42.1165890615,32.6665615328
-28,0.0605117231607,24.7237529755,6.84527564458,46.8577986502,35.3750902188
-29,0.0729799866676,25.3064823151,7.09936919054,50.4010429036,37.0154374669
-30,0.0837223082781,25.7751426697,7.24974211359,52.5587607136,37.4942081055
-31,0.0969018042088,26.0911769867,7.29583657844,53.2292313793,36.797945128
-32,0.118276156485,26.2333278656,7.23880941032,52.4003616789,34.9938471695
-33,0.153367862105,26.1958694458,7.08150773633,50.1477518197,32.2250476236
-34,0.205777496099,25.9851608276,6.8284162259,46.6272681542,28.7007747728
-35,0.275908768177,25.6171264648,6.48557683248,42.06270685,24.6820565524
-36,0.360280394554,25.1159133911,6.06048240233,36.7294469489,20.4639331805
-37,0.451779663563,24.5123958588,5.56194595701,30.9352428288,16.3553757311
-38,0.541292726994,23.8428478241,4.99994786626,24.9994786653,12.6582630106
-39,0.620634436607,23.1500606537,4.38546350048,19.232290114,9.64683245111
-40,0.685532927513,22.4845104218,3.73027428148,13.9149462151,7.54898889913
-41,0.7367426157,21.8980979919,3.04676532925,9.28277897153,6.53073029055
-42,0.778530478477,21.43110466,2.34771312875,5.5117569349,6.68473966219
-43,0.816000342369,21.1033706665,1.64606680824,2.70953593717,8.0239128394
-44,0.853178024292,20.91614151,0.954726728218,0.911503125574,10.4802592884
-45,0.892362236977,20.8606433868,0.286324124698,0.0819815043843,13.909252339
-46,0.934148788452,20.9262771606,-0.346994467836,0.120405160708,18.0993385547
-47,0.977552771568,21.1041755676,-0.933774369528,0.871934573188,22.7859690855
-48,1.0201267004,21.3851947784,-1.46344798302,2.14167999902,27.6692117065
-49,1.05826628208,21.7543334961,-1.92651479657,3.71145926141,32.433761368
-50,1.08786809444,22.1859645844,-2.31470312047,5.35785053591,36.7700056554
-51,1.1052531004,22.6443347931,-2.62111082379,6.87022195059,40.3947304297
-52,1.10810387135,23.0895843506,-2.8403226935,8.06743300321,43.0700748794
-53,1.0961625576,23.4848232269,-2.96850243314,8.81200669555,44.6194626494
-54,1.07140302658,23.800365448,-3.00345774698,9.0207584379,44.9394387343
-55,1.03744709492,24.0149841309,-2.94467741044,8.67112505153,44.006616785
-56,0.99830698967,24.1160545349,-2.7933397009,7.80274668463,41.8792699002
-57,0.956927657127,24.0998039246,-2.55229204728,6.51419469462,38.6934577812
-58,0.914133429527,23.9716682434,-2.22600224278,4.95508598485,34.6539501417
-59,0.868447780609,23.7462596893,-1.8204820461,3.31415488017,30.0205558078
-60,0.8169952631,23.4462299347,-1.34318446296,1.80414450154,25.0907755299
-61,0.75726377964,23.099729538,-0.802876444496,0.644610585127,20.1799434156
-62,0.688955187798,22.7369918823,-0.209489154746,0.0438857059564,15.6001904824
-63,0.61482322216,22.3876419067,0.426051661374,0.181520018159,11.6396428011
-64,0.539814710617,22.0797615051,1.09201234183,1.19249095471,8.54325073525
-65,0.468892633915,21.840297699,1.77605184708,3.15436016351,6.49653596831
-66,0.404858201742,21.6947250366,2.46543278485,6.07835881659,5.61334671855
-67,0.347624599934,21.6643829346,3.14723935195,9.90511553847,5.92844197967
-68,0.29546391964,21.7622184753,3.80859850763,14.5054225924,7.39540090496
-69,0.247276455164,21.9895210266,4.43690063784,19.6860872701,9.88999540961
-70,0.204171046615,22.3353061676,5.02001597792,25.2005604186,13.2187967651
-71,0.169320091605,22.7780075073,5.54650313235,30.7636969972,17.132435092
-72,0.1463367939,23.2882213593,6.00580616285,36.0697076658,21.342617878
-73,0.137272924185,23.8315925598,6.38843690887,40.8121261386,25.5417609789
-74,0.141556724906,24.371339798,6.68613945302,44.7044607852,29.423909988
-75,0.156610697508,24.8704128265,6.89203394518,47.5001319015,32.7055431859
-76,0.179717317224,25.2939338684,7.00073734674,49.010323398,35.1448553296
-77,0.20982812345,25.6120986938,7.0084590457,49.1184981952,36.5582237721
-78,0.24822832644,25.8026618958,6.91306971711,47.7905329136,36.8327479407
-79,0.297888815403,25.8517913818,6.71414225448,45.0797062135,35.9340173085
-80,0.361958742142,25.7532215118,6.412964069,41.1261081503,33.9085839082
-81,0.441900014877,25.5067844391,6.01252053609,36.1504031969,30.8809715939
-82,0.535634815693,25.1177711487,5.51744985597,30.4422529132,27.0454217042
-83,0.63624894619,24.5979499817,4.93397007671,24.3440607179,22.6529288224
-84,0.732273578644,23.968629837,4.26977949817,18.231016963,17.9944371652
-85,0.810666441917,23.2665519714,3.53393212433,12.4886762594,13.3813264572
-86,0.862254738808,22.5498809814,2.73669025242,7.48947353771,9.12449860071
-87,0.886556506157,21.8928375244,1.88935667313,3.56966863828,5.51347075848
-88,0.891611814499,21.3638858795,1.00408930024,1.00819532285,2.79688029582
-89,0.888702392578,21.0044994354,0.0937013446953,0.0087799419977,1.16571237584
-90,0.886900186539,20.8256130219,-0.828549608133,0.686494453137,0.74037823996
-91,0.890941143036,20.8187446594,-1.74918007159,3.05963092284,1.562513608
-92,0.901646256447,20.969745636,-2.65470300745,7.04744805774,3.59204958455
-93,0.91644346714,21.2676029205,-3.53185031282,12.4739666321,6.70975426768
-94,0.928477287292,21.7062892914,-4.36779170229,19.0776043546,10.7250757298
-95,0.925094485283,22.2810649872,-5.15034630396,26.5260670507,15.388760882
-96,0.88870215416,22.98295784,-5.86818341083,34.4355765431,20.4094038795
-97,0.801853656769,23.7943649292,-6.51100901154,42.3932383483,25.4728137467
-98,0.654598593712,24.6855182648,-7.06973496434,49.981152466,30.2629015337
-99,0.450378358364,25.6121520996,-7.53662797066,56.8007611681,34.4826852946
-100,0.207201644778,26.5175933838,-7.90543584503,62.4959158999,37.8740033557
+0,0.301715016365,23.9918575287,0.0,0.0,0.0
+1,0.229419589043,24.0840988159,-7.57264440482,57.3449432818,31.7160669424
+2,0.107220843434,24.3070220947,-7.87435645452,62.0054895729,35.3035396515
+3,-0.0351829528809,24.6532649994,-8.07870057495,65.2654029798,38.1221882131
+4,-0.180599540472,25.0589580536,-8.18096117119,66.9281256846,39.9580643964
+5,-0.318931311369,25.4515113831,-8.17805981355,66.880662314,40.6626090155
+6,-0.444335013628,25.7774448395,-8.06861057073,65.1024765422,40.162889391
+7,-0.55317056179,26.0078105927,-7.85294698564,61.6687763592,38.4667574053
+8,-0.642424583435,26.1305732727,-7.53312022945,56.7479003913,35.662578878
+9,-0.708554029465,26.1403503418,-7.11286845588,50.5928976706,31.9135498803
+10,-0.746821045876,26.0320796967,-6.59755786267,43.5277697512,27.4469794863
+11,-0.75127363205,25.8018722534,-5.99409644477,35.9291921892,22.5392568497
+12,-0.715579986572,25.4541931152,-5.31082188387,28.2048290822,17.4975106529
+13,-0.634981393814,25.0096435547,-4.55736545507,20.769579891,12.6391914008
+14,-0.509246230125,24.5072040558,-3.74449423598,14.0212370833,8.27094676353
+15,-0.34494766593,23.997209549,-2.88393426929,8.31707686959,4.66820782895
+16,-0.154685854912,23.524312973,-1.98817765084,3.95285037132,2.05685648579
+17,0.0463823080063,23.111574173,-1.0702767866,1.14549239994,0.59820444152
+18,0.243957415223,22.7607688904,-0.143629277806,0.0206293694431,0.378291958227
+19,0.426405906677,22.466884613,0.778242948154,0.605662086351,1.40222422628
+20,0.585257053375,22.2322635651,1.68191654683,2.82884327049,3.59392488599
+21,0.715216398239,22.0713863373,2.55428795712,6.52438696786,6.80132229929
+22,0.81441795826,22.0073051453,3.3827891733,11.443262591,10.8066192267
+23,0.885156273842,22.0636310577,4.15559446071,17.2689653219,15.3409551072
+24,0.934410214424,22.2549037933,4.86181453988,23.6372406202,20.1024751237
+25,0.97277545929,22.5800151825,5.4916749756,30.1584940376,24.7765914869
+26,1.01117730141,23.0251235962,6.03667577376,36.4414543975,29.0570752678
+27,1.05675590038,23.5736675262,6.48972950603,42.1165890615,32.6665615328
+28,1.11028766632,24.2094593048,6.84527564458,46.8577986502,35.3750902188
+29,1.16653037071,24.9071960449,7.09936919054,50.4010429036,37.0154374669
+30,1.21732020378,25.623966217,7.24974211359,52.5587607136,37.4942081055
+31,1.25560927391,26.3035640717,7.29583657844,53.2292313793,36.797945128
+32,1.27794837952,26.8886375427,7.23880941032,52.4003616789,34.9938471695
+33,1.2844671011,27.3308906555,7.08150773633,50.1477518197,32.2250476236
+34,1.27734398842,27.5969848633,6.8284162259,46.6272681542,28.7007747728
+35,1.25921845436,27.6726608276,6.48557683248,42.06270685,24.6820565524
+36,1.23247516155,27.5664672852,6.06048240233,36.7294469489,20.4639331805
+37,1.19970142841,27.3110542297,5.56194595701,30.9352428288,16.3553757311
+38,1.16478705406,26.9584217072,4.99994786626,24.9994786653,12.6582630106
+39,1.13317525387,26.5675086975,4.38546350048,19.232290114,9.64683245111
+40,1.11000192165,26.1867408752,3.73027428148,13.9149462151,7.54898889913
+41,1.09694302082,25.838809967,3.04676532925,9.28277897153,6.53073029055
+42,1.09033381939,25.5171451569,2.34771312875,5.5117569349,6.68473966219
+43,1.08199059963,25.1969871521,1.64606680824,2.70953593717,8.0239128394
+44,1.06163346767,24.8520908356,0.954726728218,0.911503125574,10.4802592884
+45,1.01915383339,24.4656162262,0.286324124698,0.0819815043843,13.909252339
+46,0.946109652519,24.0320835114,-0.346994467836,0.120405160708,18.0993385547
+47,0.836756706238,23.5550632477,-0.933774369528,0.871934573188,22.7859690855
+48,0.688973903656,23.0461997986,-1.46344798302,2.14167999902,27.6692117065
+49,0.505214512348,22.5264129639,-1.92651479657,3.71145926141,32.433761368
+50,0.293485283852,22.0246429443,-2.31470312047,5.35785053591,36.7700056554
+51,0.0675588399172,21.5696907043,-2.62111082379,6.87022195059,40.3947304297
+52,-0.155188560486,21.1789131165,-2.8403226935,8.06743300321,43.0700748794
+53,-0.358226805925,20.8529014587,-2.96850243314,8.81200669555,44.6194626494
+54,-0.529858827591,20.579328537,-3.00345774698,9.0207584379,44.9394387343
+55,-0.664429545403,20.3409194946,-2.94467741044,8.67112505153,44.006616785
+56,-0.760982990265,20.1215457916,-2.7933397009,7.80274668463,41.8792699002
+57,-0.820948839188,19.9085731506,-2.55229204728,6.51419469462,38.6934577812
+58,-0.846134305,19.6928386688,-2.22600224278,4.95508598485,34.6539501417
+59,-0.837579727173,19.4684848785,-1.8204820461,3.31415488017,30.0205558078
+60,-0.795394897461,19.2338695526,-1.34318446296,1.80414450154,25.0907755299
+61,-0.719451546669,18.9935207367,-0.802876444496,0.644610585127,20.1799434156
+62,-0.610578894615,18.759979248,-0.209489154746,0.0438857059564,15.6001904824
+63,-0.471667557955,18.5542106628,0.426051661374,0.181520018159,11.6396428011
+64,-0.308161467314,18.4038410187,1.09201234183,1.19249095471,8.54325073525
+65,-0.127842903137,18.339099884,1.77605184708,3.15436016351,6.49653596831
+66,0.0598771870136,18.3871765137,2.46543278485,6.07835881659,5.61334671855
+67,0.2450440377,18.5666713715,3.14723935195,9.90511553847,5.92844197967
+68,0.41858112812,18.8842964172,3.80859850763,14.5054225924,7.39540090496
+69,0.57379335165,19.3344478607,4.43690063784,19.6860872701,9.88999540961
+70,0.707495391369,19.9004936218,5.02001597792,25.2005604186,13.2187967651
+71,0.82030582428,20.5570163727,5.54650313235,30.7636969972,17.132435092
+72,0.915791869164,21.274061203,6.00580616285,36.0697076658,21.342617878
+73,0.998562335968,22.024187088,6.38843690887,40.8121261386,25.5417609789
+74,1.07204210758,22.7886066437,6.68613945302,44.7044607852,29.423909988
+75,1.13696241379,23.5557403564,6.89203394518,47.5001319015,32.7055431859
+76,1.19125568867,24.311460495,7.00073734674,49.010323398,35.1448553296
+77,1.23132312298,25.0295505524,7.0084590457,49.1184981952,36.5582237721
+78,1.25391471386,25.6708450317,6.91306971711,47.7905329136,36.8327479407
+79,1.25752687454,26.1906890869,6.71414225448,45.0797062135,35.9340173085
+80,1.24270105362,26.5489196777,6.412964069,41.1261081503,33.9085839082
+81,1.21143901348,26.7183036804,6.01252053609,36.1504031969,30.8809715939
+82,1.16642701626,26.6910228729,5.51744985597,30.4422529132,27.0454217042
+83,1.11066043377,26.4832611084,4.93397007671,24.3440607179,22.6529288224
+84,1.04773294926,26.1355438232,4.26977949817,18.231016963,17.9944371652
+85,0.982568979263,25.7054347992,3.53393212433,12.4886762594,13.3813264572
+86,0.921653985977,25.2521018982,2.73669025242,7.48947353771,9.12449860071
+87,0.87150812149,24.8186016083,1.88935667313,3.56966863828,5.51347075848
+88,0.835680961609,24.4230499268,1.00408930024,1.00819532285,2.79688029582
+89,0.812774062157,24.065908432,0.0937013446953,0.0087799419977,1.16571237584
+90,0.797000527382,23.7456436157,-0.828549608133,0.686494453137,0.74037823996
+91,0.780135989189,23.4684944153,-1.74918007159,3.05963092284,1.562513608
+92,0.753383994102,23.2478427887,-2.65470300745,7.04744805774,3.59204958455
+93,0.708757460117,23.0981788635,-3.53185031282,12.4739666321,6.70975426768
+94,0.640135169029,23.0297298431,-4.36779170229,19.0776043546,10.7250757298
+95,0.544076085091,23.0478630066,-5.15034630396,26.5260670507,15.388760882
+96,0.420568585396,23.1585292816,-5.86818341083,34.4355765431,20.4094038795
+97,0.274244964123,23.3723888397,-6.51100901154,42.3932383483,25.4728137467
+98,0.115107126534,23.6951541901,-7.06973496434,49.981152466,30.2629015337
+99,-0.0439793467522,24.1101932526,-7.53662797066,56.8007611681,34.4826852946
+100,-0.192170113325,24.5745697021,-7.90543584503,62.4959158999,37.8740033557
diff --git a/tests/framework/ROM/tensorflow_keras/gold/LSTMRegression/out_resampled_1.csv b/tests/framework/ROM/tensorflow_keras/gold/LSTMRegression/out_resampled_1.csv
index 207464840b..9e4e665e7b 100644
--- a/tests/framework/ROM/tensorflow_keras/gold/LSTMRegression/out_resampled_1.csv
+++ b/tests/framework/ROM/tensorflow_keras/gold/LSTMRegression/out_resampled_1.csv
@@ -1,102 +1,102 @@
index,sum,square,prev_sum,prev_square,prev_square_sum
-0,0.267201185226,23.5978221893,0.0,0.0,0.0
-1,0.222930684686,23.4306125641,5.48571680083,30.093088819,15.87093203
-2,0.149038851261,23.589427948,5.97047046237,35.6465175421,18.0772231897
-3,0.0808355808258,23.9636878967,6.4160769313,41.1660431884,20.5988298121
-4,0.0312587469816,24.4594497681,6.81550301844,46.4510813944,23.2746906398
-5,0.000335738062859,25.0037784576,7.16236129498,51.2994193199,25.9346461023
-6,-0.017595410347,25.5410518646,7.45100221818,55.5174340554,28.409219378
-7,-0.0288878381252,26.0288314819,7.67659565148,58.9301207964,30.5393586838
-8,-0.037639439106,26.4359073639,7.83520060653,61.3903685446,32.185582283
-9,-0.0446204841137,26.7416248322,7.92382220388,62.7869583187,33.2360019371
-10,-0.0476212799549,26.9349460602,7.94045503297,63.0508261307,33.6127648211
-11,-0.0425329506397,27.0125083923,7.88411228776,62.159226566,33.2765445807
-12,-0.0245631188154,26.9758968353,7.75484025865,60.1375474371,32.2288240406
-13,0.0107240825891,26.8289012909,7.55371797236,57.058655206,30.511838664
-14,0.0665967613459,26.5756340027,7.28284198469,53.0397873739,28.20618396
-15,0.144451081753,26.2202186584,6.9452965447,48.2371440938,25.4262239445
-16,0.243070885539,25.7682495117,6.54510955954,42.8384591464,22.3135638174
-17,0.357859641314,25.2290344238,6.08719499286,37.053942881,19.0289609801
-18,0.480406820774,24.6165027618,5.57728252532,31.1060803672,15.7431380431
-19,0.59918487072,23.9485435486,5.02183548873,25.2188316758,12.6270244132
-20,0.702093243599,23.2485103607,4.42795825389,19.6068142982,9.84198580776
-21,0.780415415764,22.5512084961,3.80329440417,14.4650483248,7.53060173447
-22,0.832075953484,21.9053058624,3.15591715907,9.95981311492,5.80851956504
-23,0.861710786819,21.3621997833,2.49421362379,6.22110160112,4.75785211684
-24,0.877456903458,20.9578933716,1.82676452932,3.33706864556,4.42249717623
-25,0.887217879295,20.7035827637,1.16222119262,1.35075810058,4.80564722539
-26,0.896716594696,20.5896949768,0.509181466517,0.259265765844,5.86963208313
-27,0.909299850464,20.5965118408,-0.123933536936,0.0153595215775,7.53810343927
-28,0.92636179924,20.703666687,-0.729000176437,0.531441257246,9.70043601595
-29,0.947620987892,20.8952541351,-1.29830872868,1.68560555496,12.2180930242
-30,0.971141576767,21.1604213715,-1.8246738781,3.32943476142,14.9325909838
-31,0.99342238903,21.4905948639,-2.30153766019,5.29707560125,17.6746072929
-32,1.00992429256,21.8750419617,-2.72306337785,7.41507415981,20.2737084292
-33,1.01609039307,22.2970314026,-3.08421914035,9.51240770568,22.5681410869
-34,1.00849616528,22.7327785492,-3.38084982323,11.4301455272,24.4141249485
-35,0.985679030418,23.1538906097,-3.60973641472,13.0301969838,25.6941143584
-36,0.948407530785,23.5317001343,-3.76864189496,14.2026617325,26.3235552764
-37,0.899396061897,23.8411979675,-3.85634298844,14.8713812445,26.2557501427
-38,0.842571258545,24.0634098053,-3.8726473332,14.9973973673,25.4845517538
-39,0.78206205368,24.1864891052,-3.81839581989,14.5801466374,24.0447316973
-40,0.721187114716,24.2061443329,-3.69545006737,13.6563512004,22.0100022005
-41,0.661778330803,24.1257095337,-3.506665215,12.2967009301,19.4888047636
-42,0.60410797596,23.9558429718,-3.25584842324,10.6005489551,16.6181069675
-43,0.547510743141,23.7137069702,-2.94770367952,8.68895698225,13.5555630284
-44,0.49150633812,23.4216117859,-2.58776370349,6.6965209851,10.4704874671
-45,0.436881065369,23.1052474976,-2.18230993111,4.76247663541,7.53415930252
-46,0.385999292135,22.7915382385,-1.73828172866,3.0216233682,4.91001255501
-47,0.341957747936,22.5058708191,-1.26317614264,1.59561396733,2.74427536676
-48,0.307024866343,22.2687091827,-0.764939627466,0.585132633668,1.1575943291
-49,0.281464129686,22.0924396515,-0.251853308576,0.0634300890409,0.238124134119
-50,0.263565957546,21.9799785614,0.2675865688,0.0716025718021,0.0364786705157
-51,0.250753223896,21.9260597229,0.784791285476,0.61589736176,0.562832980227
-52,0.240937769413,21.9207363129,1.29120362461,1.66720680021,1.78634219808
-53,0.233388274908,21.9536476135,1.77842139518,3.16278265883,3.6369107796
-54,0.228873431683,22.0176277161,2.23831872582,5.01007071836,6.00921059603
-55,0.229235932231,22.1106281281,2.66316338438,7.09243921192,8.76871756308
-56,0.236665457487,22.2353935242,3.04572843554,9.27646170306,11.7594207614
-57,0.252922445536,22.3968048096,3.37939663045,11.4203215859,14.8127621347
-58,0.27870798111,22.5975456238,3.65825602677,13.3828371574,17.7572943105
-59,0.313362330198,22.8337287903,3.8771854637,15.03256712,20.4285029274
-60,0.355026304722,23.0923347473,4.03192866236,16.2564487383,22.6782304198
-61,0.401253819466,23.3515796661,4.11915588565,16.9674452103,24.3831610641
-62,0.449773222208,23.584104538,4.13651227065,17.1107337653,25.4518808998
-63,0.498968929052,23.7617778778,4.08265213801,16.66804848,25.8301078383
-64,0.547840893269,23.8604793549,3.95725878493,15.6598970909,25.5037921637
-65,0.595531642437,23.8635311127,3.76104947672,14.1454931664,24.4999097096
-66,0.640719056129,23.7633533478,3.49576556508,12.220376886,22.8849022653
-67,0.681211590767,23.5619812012,3.16414787491,10.0118317743,20.7608546324
-68,0.714052796364,23.2713317871,2.76989771369,7.67233334428,18.2596275034
-69,0.736318230629,22.9136199951,2.31762406383,5.37138130123,15.5352825119
-70,0.746458768845,22.5209827423,1.81277771749,3.28616305303,12.7552337081
-71,0.745499134064,22.1325092316,1.26157330097,1.59156719372,10.0906327201
-72,0.737138748169,21.7878437042,0.67090030996,0.450107225905,7.70653879158
-73,0.7264367342,21.5197544098,0.0482244351478,0.00232559614532,5.75243721768
-74,0.717892765999,21.349445343,-0.5985194029,0.358225475647,4.35364973468
-75,0.714147865772,21.2862968445,-1.2610407712,1.59022382664,3.60412928557
-76,0.715818047523,21.330871582,-1.93081255883,3.72803713733,3.56105222974
-77,0.722059130669,21.4789657593,-2.59919321932,6.75580539136,4.24151802824
-78,0.731058120728,21.7250022888,-3.25755066309,10.6116363226,5.62154562833
-79,0.739827990532,22.0638427734,-3.897386018,15.1896177733,7.63742411617
-80,0.743307590485,22.4907531738,-4.51045547831,20.3442086218,10.1893402511
-81,0.733612179756,23.0001468658,-5.08888848962,25.8967860598,13.1470749764
-82,0.700665950775,23.5840816498,-5.62530057006,31.6440065035,16.3574423984
-83,0.634665906429,24.2308616638,-6.11289914535,37.3675359613,19.6530448452
-84,0.529534220695,24.9232807159,-6.54558087557,42.8446289986,22.8618421684
-85,0.385912418365,25.6368331909,-6.91801907393,47.8589879073,25.8169867818
-86,0.212339967489,26.3395671844,-7.22573996057,52.2113179778,28.3663606943
-87,0.0237867981195,26.9947032928,-7.46518665453,55.7290117869,30.3812678805
-88,-0.162153720856,27.5656929016,-7.63376998379,58.2744441655,31.7637837509
-89,-0.329814225435,28.0223827362,-7.72990538283,59.7514372274,32.4523404646
-90,-0.468687206507,28.3460540771,-7.75303534687,60.1095570898,32.4252279576
-91,-0.574230194092,28.5308685303,-7.70363712034,59.3460248819,31.7018100382
-92,-0.646651864052,28.5811386108,-7.58321550879,57.5051574527,30.341385883
-93,-0.688950419426,28.5065174103,-7.39428091795,54.6753902936,28.4397622445
-94,-0.705251455307,28.317647934,-7.14031293596,50.9840688235,26.1237329086
-95,-0.699849128723,28.0239105225,-6.82570998246,46.5903167647,23.5437819089
-96,-0.676861763,27.633687973,-6.45572574909,41.6763949475,20.8654288251
-97,-0.6402374506,27.1567344666,-6.03639334556,36.4380446223,18.2597123309
-98,-0.593736290932,26.6075935364,-5.57443824234,31.0743617177,15.8933575617
-99,-0.540578365326,26.0082836151,-5.07718126238,25.7777695711,13.9191909899
-100,-0.48276129365,25.3883628845,-4.55243301702,20.7246463745,12.4673523124
+0,0.309352308512,24.0071716309,0.0,0.0,0.0
+1,0.396279752254,24.1006088257,5.48571680083,30.093088819,15.87093203
+2,0.500626087189,24.2868785858,5.97047046237,35.6465175421,18.0772231897
+3,0.615488409996,24.5597705841,6.4160769313,41.1660431884,20.5988298121
+4,0.736331701279,24.9189720154,6.81550301844,46.4510813944,23.2746906398
+5,0.857904314995,25.3638343811,7.16236129498,51.2994193199,25.9346461023
+6,0.973170280457,25.8886814117,7.45100221818,55.5174340554,28.409219378
+7,1.07432663441,26.4772491455,7.67659565148,58.9301207964,30.5393586838
+8,1.15498507023,27.1010398865,7.83520060653,61.3903685446,32.185582283
+9,1.21194863319,27.7230873108,7.92382220388,62.7869583187,33.2360019371
+10,1.24561607838,28.3039913177,7.94045503297,63.0508261307,33.6127648211
+11,1.25913918018,28.8067378998,7.88411228776,62.159226566,33.2765445807
+12,1.25707554817,29.1989631653,7.75484025865,60.1375474371,32.2288240406
+13,1.24416053295,29.4533653259,7.55371797236,57.058655206,30.511838664
+14,1.22442865372,29.5477828979,7.28284198469,53.0397873739,28.20618396
+15,1.20064556599,29.4666862488,6.9452965447,48.2371440938,25.4262239445
+16,1.17401719093,29.2051181793,6.54510955954,42.8384591464,22.3135638174
+17,1.14434587955,28.7745800018,6.08719499286,37.053942881,19.0289609801
+18,1.11097931862,28.207906723,5.57728252532,31.1060803672,15.7431380431
+19,1.07459330559,27.5585842133,5.02183548873,25.2188316758,12.6270244132
+20,1.03877806664,26.8920021057,4.42795825389,19.6068142982,9.84198580776
+21,1.00962400436,26.270532608,3.80329440417,14.4650483248,7.53060173447
+22,0.992751955986,25.7368564606,3.15591715907,9.95981311492,5.80851956504
+23,0.989789128304,25.3017978668,2.49421362379,6.22110160112,4.75785211684
+24,0.997075915337,24.9453964233,1.82676452932,3.33706864556,4.42249717623
+25,1.0071901083,24.6326732635,1.16222119262,1.35075810058,4.80564722539
+26,1.01140320301,24.3321266174,0.509181466517,0.259265765844,5.86963208313
+27,1.00137078762,24.0250530243,-0.123933536936,0.0153595215775,7.53810343927
+28,0.969933271408,23.7049732208,-0.729000176437,0.531441257246,9.70043601595
+29,0.911587715149,23.3730583191,-1.29830872868,1.68560555496,12.2180930242
+30,0.823001146317,23.0348510742,-1.8246738781,3.32943476142,14.9325909838
+31,0.703559160233,22.7000770569,-2.30153766019,5.29707560125,17.6746072929
+32,0.555826425552,22.3839626312,-2.72306337785,7.41507415981,20.2737084292
+33,0.385879546404,22.1062679291,-3.08421914035,9.51240770568,22.5681410869
+34,0.203271508217,21.8856182098,-3.38084982323,11.4301455272,24.4141249485
+35,0.0200037956238,21.7316131592,-3.60973641472,13.0301969838,25.6941143584
+36,-0.151661962271,21.6405582428,-3.76864189496,14.2026617325,26.3235552764
+37,-0.301582843065,21.5975131989,-3.85634298844,14.8713812445,26.2557501427
+38,-0.423045128584,21.5821838379,-3.8726473332,14.9973973673,25.4845517538
+39,-0.512620449066,21.5744438171,-3.81839581989,14.5801466374,24.0447316973
+40,-0.569092392921,21.5573635101,-3.69545006737,13.6563512004,22.0100022005
+41,-0.592229127884,21.5180988312,-3.506665215,12.2967009301,19.4888047636
+42,-0.581963062286,21.4479789734,-3.25584842324,10.6005489551,16.6181069675
+43,-0.538252830505,21.3428936005,-2.94770367952,8.68895698225,13.5555630284
+44,-0.461624771357,21.2041244507,-2.58776370349,6.6965209851,10.4704874671
+45,-0.35410246253,21.0389671326,-2.18230993111,4.76247663541,7.53415930252
+46,-0.219972342253,20.8601837158,-1.73828172866,3.0216233682,4.91001255501
+47,-0.0658738911152,20.6839752197,-1.26317614264,1.59561396733,2.74427536676
+48,0.0998588502407,20.5270900726,-0.764939627466,0.585132633668,1.1575943291
+49,0.268248856068,20.4040298462,-0.251853308576,0.0634300890409,0.238124134119
+50,0.430704295635,20.3251228333,0.2675865688,0.0716025718021,0.0364786705157
+51,0.579788327217,20.2959690094,0.784791285476,0.61589736176,0.562832980227
+52,0.709668397903,20.3182487488,1.29120362461,1.66720680021,1.78634219808
+53,0.816288352013,20.391242981,1.77842139518,3.16278265883,3.6369107796
+54,0.89740717411,20.51304245,2.23831872582,5.01007071836,6.00921059603
+55,0.952634811401,20.6806163788,2.66316338438,7.09243921192,8.76871756308
+56,0.983466744423,20.8886680603,3.04572843554,9.27646170306,11.7594207614
+57,0.993147611618,21.1281509399,3.37939663045,11.4203215859,14.8127621347
+58,0.986135721207,21.3860797882,3.65825602677,13.3828371574,17.7572943105
+59,0.967175483704,21.6478176117,3.8771854637,15.03256712,20.4285029274
+60,0.940330266953,21.9007835388,4.03192866236,16.2564487383,22.6782304198
+61,0.908409953117,22.1363372803,4.11915588565,16.9674452103,24.3831610641
+62,0.872915029526,22.3477401733,4.13651227065,17.1107337653,25.4518808998
+63,0.834348201752,22.5263347626,4.08265213801,16.66804848,25.8301078383
+64,0.792746543884,22.6601047516,3.95725878493,15.6598970909,25.5037921637
+65,0.748282313347,22.7362594604,3.76104947672,14.1454931664,24.4999097096
+66,0.701722025871,22.7458229065,3.49576556508,12.220376886,22.8849022653
+67,0.654583692551,22.68724823,3.16414787491,10.0118317743,20.7608546324
+68,0.609021067619,22.5674381256,2.76989771369,7.67233334428,18.2596275034
+69,0.567573904991,22.4000968933,2.31762406383,5.37138130123,15.5352825119
+70,0.532886147499,22.2023487091,1.81277771749,3.28616305303,12.7552337081
+71,0.507344782352,21.9910583496,1.26157330097,1.59156719372,10.0906327201
+72,0.492535561323,21.7803993225,0.67090030996,0.450107225905,7.70653879158
+73,0.488579571247,21.5816078186,0.0482244351478,0.00232559614532,5.75243721768
+74,0.493670374155,21.404548645,-0.5985194029,0.358225475647,4.35364973468
+75,0.504111051559,21.2596263885,-1.2610407712,1.59022382664,3.60412928557
+76,0.514856934547,21.1585083008,-1.93081255883,3.72803713733,3.56105222974
+77,0.520292282104,21.1132774353,-2.59919321932,6.75580539136,4.24151802824
+78,0.514941394329,21.1345367432,-3.25755066309,10.6116363226,5.62154562833
+79,0.493950754404,21.2294216156,-3.897386018,15.1896177733,7.63742411617
+80,0.453333258629,21.4004669189,-4.51045547831,20.3442086218,10.1893402511
+81,0.390149712563,21.6464614868,-5.08888848962,25.8967860598,13.1470749764
+82,0.303062319756,21.9654026031,-5.62530057006,31.6440065035,16.3574423984
+83,0.19357471168,22.356098175,-6.11289914535,37.3675359613,19.6530448452
+84,0.0671241432428,22.8139724731,-6.54558087557,42.8446289986,22.8618421684
+85,-0.0676289200783,23.3233680725,-6.91801907393,47.8589879073,25.8169867818
+86,-0.201394885778,23.8544006348,-7.22573996057,52.2113179778,28.3663606943
+87,-0.326856046915,24.3685722351,-7.46518665453,55.7290117869,30.3812678805
+88,-0.439756780863,24.8293991089,-7.63376998379,58.2744441655,31.7637837509
+89,-0.53850710392,25.2108726501,-7.72990538283,59.7514372274,32.4523404646
+90,-0.623111128807,25.4999351501,-7.75303534687,60.1095570898,32.4252279576
+91,-0.69409263134,25.6942024231,-7.70363712034,59.3460248819,31.7018100382
+92,-0.751692533493,25.7976074219,-7.58321550879,57.5051574527,30.341385883
+93,-0.795375227928,25.8158893585,-7.39428091795,54.6753902936,28.4397622445
+94,-0.82360625267,25.753112793,-7.14031293596,50.9840688235,26.1237329086
+95,-0.833904743195,25.6101722717,-6.82570998246,46.5903167647,23.5437819089
+96,-0.823221564293,25.3861408234,-6.45572574909,41.6763949475,20.8654288251
+97,-0.788672804832,25.0822181702,-6.03639334556,36.4380446223,18.2597123309
+98,-0.728544354439,24.7063045502,-5.57443824234,31.0743617177,15.8933575617
+99,-0.643340945244,24.2753868103,-5.07718126238,25.7777695711,13.9191909899
+100,-0.536521077156,23.8140258789,-4.55243301702,20.7246463745,12.4673523124
diff --git a/tests/framework/ROM/tensorflow_keras/gold/data/outCon1DClassifier.csv b/tests/framework/ROM/tensorflow_keras/gold/data/outCon1DClassifier.csv
index dfd3250b25..9e698c3c24 100644
--- a/tests/framework/ROM/tensorflow_keras/gold/data/outCon1DClassifier.csv
+++ b/tests/framework/ROM/tensorflow_keras/gold/data/outCon1DClassifier.csv
@@ -7,30 +7,30 @@ time,x,y
0.5625,16.0,17.0
0.675,17.0,17.0
0.7875,18.0,17.0
-0.0,2.0,9.0
-0.1125,3.0,9.0
-0.225,4.0,9.0
-0.3375,5.0,9.0
-0.45,6.0,9.0
-0.5625,7.0,9.0
-0.675,8.0,9.0
-0.7875,9.0,9.0
-0.0,3.0,9.0
-0.1125,4.0,9.0
-0.225,5.0,9.0
-0.3375,6.0,9.0
-0.45,7.0,9.0
-0.5625,8.0,9.0
-0.675,9.0,9.0
-0.7875,10.0,9.0
-0.0,5.0,13.0
-0.1125,6.0,13.0
-0.225,7.0,13.0
-0.3375,8.0,13.0
-0.45,9.0,13.0
-0.5625,10.0,13.0
-0.675,11.0,13.0
-0.7875,12.0,13.0
+0.0,2.0,11.0
+0.1125,3.0,11.0
+0.225,4.0,11.0
+0.3375,5.0,11.0
+0.45,6.0,11.0
+0.5625,7.0,11.0
+0.675,8.0,11.0
+0.7875,9.0,11.0
+0.0,3.0,11.0
+0.1125,4.0,11.0
+0.225,5.0,11.0
+0.3375,6.0,11.0
+0.45,7.0,11.0
+0.5625,8.0,11.0
+0.675,9.0,11.0
+0.7875,10.0,11.0
+0.0,5.0,14.0
+0.1125,6.0,14.0
+0.225,7.0,14.0
+0.3375,8.0,14.0
+0.45,9.0,14.0
+0.5625,10.0,14.0
+0.675,11.0,14.0
+0.7875,12.0,14.0
0.0,7.0,15.0
0.1125,8.0,15.0
0.225,9.0,15.0
@@ -55,22 +55,22 @@ time,x,y
0.5625,18.0,17.0
0.675,19.0,17.0
0.7875,20.0,17.0
-0.0,5.0,13.0
-0.1125,6.0,13.0
-0.225,7.0,13.0
-0.3375,8.0,13.0
-0.45,9.0,13.0
-0.5625,10.0,13.0
-0.675,11.0,13.0
-0.7875,12.0,13.0
-0.0,5.0,13.0
-0.1125,6.0,13.0
-0.225,7.0,13.0
-0.3375,8.0,13.0
-0.45,9.0,13.0
-0.5625,10.0,13.0
-0.675,11.0,13.0
-0.7875,12.0,13.0
+0.0,5.0,14.0
+0.1125,6.0,14.0
+0.225,7.0,14.0
+0.3375,8.0,14.0
+0.45,9.0,14.0
+0.5625,10.0,14.0
+0.675,11.0,14.0
+0.7875,12.0,14.0
+0.0,5.0,14.0
+0.1125,6.0,14.0
+0.225,7.0,14.0
+0.3375,8.0,14.0
+0.45,9.0,14.0
+0.5625,10.0,14.0
+0.675,11.0,14.0
+0.7875,12.0,14.0
0.0,6.0,14.0
0.1125,7.0,14.0
0.225,8.0,14.0
diff --git a/tests/framework/ROM/tensorflow_keras/gold/data/outLSTMClassifier.csv b/tests/framework/ROM/tensorflow_keras/gold/data/outLSTMClassifier.csv
index b6a54c5478..0acc39c774 100644
--- a/tests/framework/ROM/tensorflow_keras/gold/data/outLSTMClassifier.csv
+++ b/tests/framework/ROM/tensorflow_keras/gold/data/outLSTMClassifier.csv
@@ -1,7 +1,7 @@
time,x,y
-0.0,14.0,23.0
-0.3,15.0,23.0
-0.6,16.0,23.0
+0.0,14.0,24.0
+0.3,15.0,24.0
+0.6,16.0,24.0
0.0,2.0,3.0
0.3,3.0,3.0
0.6,4.0,3.0
@@ -14,12 +14,12 @@ time,x,y
0.0,9.0,3.0
0.3,10.0,3.0
0.6,11.0,3.0
-0.0,20.0,23.0
-0.3,21.0,23.0
-0.6,22.0,23.0
-0.0,18.0,23.0
-0.3,19.0,23.0
-0.6,20.0,23.0
+0.0,20.0,24.0
+0.3,21.0,24.0
+0.6,22.0,24.0
+0.0,18.0,24.0
+0.3,19.0,24.0
+0.6,20.0,24.0
0.0,6.0,3.0
0.3,7.0,3.0
0.6,8.0,3.0
diff --git a/tests/framework/ROM/tensorflow_keras/gold/diabetes/outMLPClassifier.csv b/tests/framework/ROM/tensorflow_keras/gold/diabetes/outMLPClassifier.csv
index 5d44c222de..4e6ceeb1cd 100644
--- a/tests/framework/ROM/tensorflow_keras/gold/diabetes/outMLPClassifier.csv
+++ b/tests/framework/ROM/tensorflow_keras/gold/diabetes/outMLPClassifier.csv
@@ -27,7 +27,7 @@ x1,x2,x3,x4,x5,x6,x7,x8,y
0.0,181.0,88.0,44.0,510.0,43.3,0.222,26.0,1.0
8.0,154.0,78.0,32.0,0.0,32.4,0.443,45.0,1.0
1.0,128.0,88.0,39.0,110.0,36.5,1.057,37.0,1.0
-7.0,137.0,90.0,41.0,0.0,32.0,0.391,39.0,0.0
+7.0,137.0,90.0,41.0,0.0,32.0,0.391,39.0,1.0
0.0,123.0,72.0,0.0,0.0,36.3,0.258,52.0,0.0
1.0,106.0,76.0,0.0,0.0,37.5,0.197,26.0,0.0
6.0,190.0,92.0,0.0,0.0,35.5,0.278,66.0,1.0
diff --git a/tests/framework/user_guide/ravenTutorial/RomLoad.xml b/tests/framework/user_guide/ravenTutorial/RomLoad.xml
index 9fa826620e..675963c665 100644
--- a/tests/framework/user_guide/ravenTutorial/RomLoad.xml
+++ b/tests/framework/user_guide/ravenTutorial/RomLoad.xml
@@ -23,11 +23,7 @@
-
- sigma-A,decay-A
- A, time
-
diff --git a/framework/SupervisedLearning/KerasBase.py b/framework/SupervisedLearning/KerasBase.py
index 48b63277b2..0cbee14c90 100644
--- a/framework/SupervisedLearning/KerasBase.py
+++ b/framework/SupervisedLearning/KerasBase.py
@@ -227,13 +227,7 @@ def readInitDict(self, initDict):
self._ROM = None
# the training/testing history of ROM
self._romHistory = None
- self._sessionConf = None
randomSeed = self.initOptionDict.pop('random_seed',None)
- # Force TensorFlow to use single thread when reproducible results are requested
- # Multiple threads are a potential source of non-reproducible results.
- # For further details, see: https://stackoverflow.com/questions/42022950/
- self._sessionConf = tf.ConfigProto(intra_op_parallelism_threads=self.numThreads,
- inter_op_parallelism_threads=self.numThreads)
# Set the seed for random number generation to obtain reproducible results
# https://keras.io/getting-started/faq/#how-can-i-obtain-reproducible-results-using-keras-during-development
if randomSeed is not None:
@@ -243,18 +237,11 @@ def readInitDict(self, initDict):
# The below is necessary for starting core Python generated random numbers
# in a well-defined state.
rn.seed(randomSeed)
# The below tf.set_random_seed() will make random number generation
# in the TensorFlow backend have a well-defined initial state.
# For further details, see:
- # https://www.tensorflow.org/api_docs/python/tf/set_random_seed
- tf.set_random_seed(randomSeed)
- self._session = tf.Session(graph=tf.get_default_graph(), config=self._sessionConf)
- # Base on issue https://github.com/tensorflow/tensorflow/issues/28287
- # The problem is that tensorflow graphs and sessions are not thread safe. So by default
- # a new session (which) does not contain any previously loaded weights, models, and so on)
- # is created for each thread, i.e. for each request. By saving the session that contains all
- # the models and setting it to be used by keras in each thread.
- tf.keras.backend.set_session(self._session)
+ # https://www.tensorflow.org/api_docs/python/tf/random/set_seed
+ tf.random.set_seed(randomSeed)
modelName = self.initOptionDict.pop('name','')
# number of classes for classifier
@@ -300,9 +287,7 @@ def _initGraph(self):
@ In, None
@ Out, None
"""
- # This is needed to solve the thread issue in self._ROM.predict()
- # https://github.com/fchollet/keras/issues/2397#issuecomment-306687500
- self.graph = tf.get_default_graph()
+ pass
def __getstate__(self):
"""
@@ -311,7 +296,7 @@ def __getstate__(self):
@ Out, state, dict, it contains all the information needed by the ROM to be initialized
"""
state = supervisedLearning.__getstate__(self)
- tf.keras.models.save_model(self._ROM, KerasBase.tempModelFile)
+ tf.keras.models.save_model(self._ROM, KerasBase.tempModelFile, save_format='h5')
# another method to save the TensorFlow model
# self._ROM.save(KerasBase.tempModelFile)
with open(KerasBase.tempModelFile, "rb") as f:
@@ -331,7 +316,6 @@ def __setstate__(self, d):
with open(KerasBase.tempModelFile, "wb") as f:
f.write(d[KerasBase.modelAttr])
del d[KerasBase.modelAttr]
- tf.keras.backend.set_session(self._session)
self._ROM = tf.keras.models.load_model(KerasBase.tempModelFile)
os.remove(KerasBase.tempModelFile)
self.__dict__.update(d)
@@ -348,8 +332,8 @@ def writeXML(self, writeTo, targets=None, skip=None):
if not self.amITrained:
self.raiseAnError(RuntimeError, 'ROM is not yet trained! Cannot write to DataObject.')
root = writeTo.getRoot()
- writeTo.addScalar('Accuracy',"Training",' '.join([str(elm) for elm in self._romHistory.history['acc']]))
- writeTo.addScalar('Accuracy',"Testing",' '.join([str(elm) for elm in self._romHistory.history['val_acc']]))
+ writeTo.addScalar('Accuracy',"Training",' '.join([str(elm) for elm in self._romHistory.history['accuracy']]))
+ writeTo.addScalar('Accuracy',"Testing",' '.join([str(elm) for elm in self._romHistory.history['val_accuracy']]))
writeTo.addScalar('Loss',"Training",' '.join([str(elm) for elm in self._romHistory.history['loss']]))
writeTo.addScalar('Loss',"Testing",' '.join([str(elm) for elm in self._romHistory.history['val_loss']]))
@@ -465,7 +449,6 @@ def __trainLocal__(self,featureVals,targetVals):
#output layer
self._addOutputLayers()
self._ROM.compile(loss=self.lossFunction, optimizer=self.optimizer, metrics=self.metrics)
- self._ROM._make_predict_function() # have to initialize before threading
self._romHistory = self._ROM.fit(featureVals, targetVals, epochs=self.epochs, batch_size=self.batchSize, validation_split=self.validationSplit)
# The following requires pydot-ng and graphviz to be installed (See the manual)
# https://github.com/keras-team/keras/issues/3210
@@ -490,9 +473,7 @@ def __evaluateLocal__(self,featureVals):
"""
featureVals = self._preprocessInputs(featureVals)
prediction = {}
- with self.graph.as_default():
- tf.keras.backend.set_session(self._session)
- outcome = self._ROM.predict(featureVals)
+ outcome = self._ROM.predict(featureVals)
if self.numClasses > 1 and self.lossFunction in ['categorical_crossentropy']:
outcome = np.argmax(outcome,axis=1)
# Transform labels back to original encoding
@@ -243,18 +237,11 @@ def readInitDict(self, initDict):
# in a well-defined state.
rn.seed(randomSeed)
- # The below tf.set_random_seed() will make random number generation
+ # The below tf.random.set_seed() will make random number generation
# in the TensorFlow backend have a well-defined initial state.
# For further details, see: